@@ -1,55 +1,33 @@
 
 /*
-   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
-   All rights reserved.
+   SPDX-FileCopyrightText: 2003-2007 Clarence Dang <dang@kde.org>
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   1. Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-   2. Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   SPDX-License-Identifier: BSD-2-Clause
 */
 
-
 #define DEBUG_KP_DOCUMENT 0
 
-
 #include "kpDocument.h"
 #include "kpDocumentPrivate.h"
 
-#include "layers/selections/kpAbstractSelection.h"
-#include "layers/selections/image/kpAbstractImageSelection.h"
-#include "imagelib/kpColor.h"
-#include "widgets/toolbars/kpColorToolBar.h"
-#include "kpDefs.h"
-#include "environments/document/kpDocumentEnvironment.h"
 #include "document/kpDocumentSaveOptions.h"
-#include "imagelib/kpDocumentMetaInfo.h"
+#include "environments/document/kpDocumentEnvironment.h"
 #include "imagelib/effects/kpEffectReduceColors.h"
-#include "tools/kpTool.h"
-#include "widgets/toolbars/kpToolToolBar.h"
+#include "imagelib/kpColor.h"
+#include "imagelib/kpDocumentMetaInfo.h"
+#include "kpDefs.h"
+#include "layers/selections/image/kpAbstractImageSelection.h"
+#include "layers/selections/kpAbstractSelection.h"
 #include "lgpl/generic/kpUrlFormatter.h"
+#include "tools/kpTool.h"
+#include "widgets/toolbars/kpColorToolBar.h"
+#include "widgets/toolbars/kpToolToolBar.h"
 #include <kio_version.h>
 
 #include "kpLogCategories.h"
+#include <KIO/StatJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
-#include <KIO/StatJob>
 
 #include <QColor>
 #include <QImage>
@@ -58,18 +36,19 @@
 
 //---------------------------------------------------------------------
 
-kpDocument::kpDocument (int w, int h,
-        kpDocumentEnvironment *environ)
-    : QObject (),
-      m_constructorWidth (w), m_constructorHeight (h),
-      m_isFromExistingURL (false),
-      m_savedAtLeastOnceBefore (false),
-      m_saveOptions (new kpDocumentSaveOptions ()),
-      m_metaInfo (new kpDocumentMetaInfo ()),
-      m_modified (false),
-      m_selection (nullptr),
-      m_oldWidth (-1), m_oldHeight (-1),
-      d (new kpDocumentPrivate ())
+kpDocument::kpDocument(int w, int h, kpDocumentEnvironment *environ)
+    : QObject()
+    , m_constructorWidth(w)
+    , m_constructorHeight(h)
+    , m_isFromExistingURL(false)
+    , m_savedAtLeastOnceBefore(false)
+    , m_saveOptions(new kpDocumentSaveOptions())
+    , m_metaInfo(new kpDocumentMetaInfo())
+    , m_modified(false)
+    , m_selection(nullptr)
+    , m_oldWidth(-1)
+    , m_oldHeight(-1)
+    , d(new kpDocumentPrivate())
 {
 #if DEBUG_KP_DOCUMENT && 0
     qCDebug(kpLogDocument) << "kpDocument::kpDocument (" << w << "," << h << ")";
@@ -83,7 +62,7 @@ kpDocument::kpDocument (int w, int h,
 
 //---------------------------------------------------------------------
 
-kpDocument::~kpDocument ()
+kpDocument::~kpDocument()
 {
     delete d;
 
@@ -98,7 +77,7 @@ kpDocument::~kpDocument ()
 //---------------------------------------------------------------------
 
 // public
-kpDocumentEnvironment *kpDocument::environ () const
+kpDocumentEnvironment *kpDocument::environ() const
 {
     return d->environ;
 }
@@ -106,7 +85,7 @@ kpDocumentEnvironment *kpDocument::environ () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setEnviron (kpDocumentEnvironment *environ)
+void kpDocument::setEnviron(kpDocumentEnvironment *environ)
 {
     d->environ = environ;
 }
@@ -114,7 +93,7 @@ void kpDocument::setEnviron (kpDocumentEnvironment *environ)
 //---------------------------------------------------------------------
 
 // public
-bool kpDocument::savedAtLeastOnceBefore () const
+bool kpDocument::savedAtLeastOnceBefore() const
 {
     return m_savedAtLeastOnceBefore;
 }
@@ -122,7 +101,7 @@ bool kpDocument::savedAtLeastOnceBefore () const
 //---------------------------------------------------------------------
 
 // public
-QUrl kpDocument::url () const
+QUrl kpDocument::url() const
 {
     return m_url;
 }
@@ -130,7 +109,7 @@ QUrl kpDocument::url () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setURL (const QUrl &url, bool isFromExistingURL)
+void kpDocument::setURL(const QUrl &url, bool isFromExistingURL)
 {
     m_url = url;
     m_isFromExistingURL = isFromExistingURL;
@@ -139,7 +118,7 @@ void kpDocument::setURL (const QUrl &url, bool isFromExistingURL)
 //---------------------------------------------------------------------
 
 // public
-bool kpDocument::isFromExistingURL () const
+bool kpDocument::isFromExistingURL() const
 {
     return m_isFromExistingURL;
 }
@@ -147,36 +126,36 @@ bool kpDocument::isFromExistingURL () const
 //---------------------------------------------------------------------
 
 // public
-bool kpDocument::urlExists (const QUrl &url) const
+bool kpDocument::urlExists(const QUrl &url) const
 {
     if (url.isEmpty()) {
         return false;
     }
     KIO::StatJob *job = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
-    KJobWidgets::setWindow (job, d->environ->dialogParent ());
+    KJobWidgets::setWindow(job, d->environ->dialogParent());
     return job->exec();
 }
 
 //---------------------------------------------------------------------
 
 // public
-QString kpDocument::prettyUrl () const
+QString kpDocument::prettyUrl() const
 {
-    return kpUrlFormatter::PrettyUrl (m_url);
+    return kpUrlFormatter::PrettyUrl(m_url);
 }
 
 //---------------------------------------------------------------------
 
 // public
-QString kpDocument::prettyFilename () const
+QString kpDocument::prettyFilename() const
 {
-    return kpUrlFormatter::PrettyFilename (m_url);
+    return kpUrlFormatter::PrettyFilename(m_url);
 }
 
 //---------------------------------------------------------------------
 
 // public
-const kpDocumentSaveOptions *kpDocument::saveOptions () const
+const kpDocumentSaveOptions *kpDocument::saveOptions() const
 {
     return m_saveOptions;
 }
@@ -184,7 +163,7 @@ const kpDocumentSaveOptions *kpDocument::saveOptions () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setSaveOptions (const kpDocumentSaveOptions &saveOptions)
+void kpDocument::setSaveOptions(const kpDocumentSaveOptions &saveOptions)
 {
     *m_saveOptions = saveOptions;
 }
@@ -192,7 +171,7 @@ void kpDocument::setSaveOptions (const kpDocumentSaveOptions &saveOptions)
 //---------------------------------------------------------------------
 
 // public
-const kpDocumentMetaInfo *kpDocument::metaInfo () const
+const kpDocumentMetaInfo *kpDocument::metaInfo() const
 {
     return m_metaInfo;
 }
@@ -200,7 +179,7 @@ const kpDocumentMetaInfo *kpDocument::metaInfo () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setMetaInfo (const kpDocumentMetaInfo &metaInfo)
+void kpDocument::setMetaInfo(const kpDocumentMetaInfo &metaInfo)
 {
     *m_metaInfo = metaInfo;
 }
@@ -211,7 +190,7 @@ void kpDocument::setMetaInfo (const kpDocumentMetaInfo &metaInfo)
  * Properties
  */
 
-void kpDocument::setModified (bool yes)
+void kpDocument::setModified(bool yes)
 {
     if (yes == m_modified) {
         return;
@@ -220,83 +199,83 @@ void kpDocument::setModified (bool yes)
     m_modified = yes;
 
     if (yes) {
-        Q_EMIT documentModified ();
+        Q_EMIT documentModified();
     }
 }
 
 //---------------------------------------------------------------------
 
-bool kpDocument::isModified () const
+bool kpDocument::isModified() const
 {
     return m_modified;
 }
 
 //---------------------------------------------------------------------
 
-bool kpDocument::isEmpty () const
+bool kpDocument::isEmpty() const
 {
-    return url ().isEmpty () && !isModified ();
+    return url().isEmpty() && !isModified();
 }
 
 //---------------------------------------------------------------------
 
-int kpDocument::constructorWidth () const
+int kpDocument::constructorWidth() const
 {
     return m_constructorWidth;
 }
 
 //---------------------------------------------------------------------
 
-int kpDocument::width (bool ofSelection) const
+int kpDocument::width(bool ofSelection) const
 {
     return (ofSelection && m_selection) ? m_selection->width() : m_image->width();
 }
 
 //---------------------------------------------------------------------
 
-int kpDocument::oldWidth () const
+int kpDocument::oldWidth() const
 {
     return m_oldWidth;
 }
 
 //---------------------------------------------------------------------
 
-void kpDocument::setWidth (int w, const kpColor &backgroundColor)
+void kpDocument::setWidth(int w, const kpColor &backgroundColor)
 {
-    resize (w, height (), backgroundColor);
+    resize(w, height(), backgroundColor);
 }
 
 //---------------------------------------------------------------------
 
-int kpDocument::constructorHeight () const
+int kpDocument::constructorHeight() const
 {
     return m_constructorHeight;
 }
 
 //---------------------------------------------------------------------
 
-int kpDocument::height (bool ofSelection) const
+int kpDocument::height(bool ofSelection) const
 {
     return (ofSelection && m_selection) ? m_selection->height() : m_image->height();
 }
 
 //---------------------------------------------------------------------
 
-int kpDocument::oldHeight () const
+int kpDocument::oldHeight() const
 {
     return m_oldHeight;
 }
 
 //---------------------------------------------------------------------
 
-void kpDocument::setHeight (int h, const kpColor &backgroundColor)
+void kpDocument::setHeight(int h, const kpColor &backgroundColor)
 {
-    resize (width (), h, backgroundColor);
+    resize(width(), h, backgroundColor);
 }
 
 //---------------------------------------------------------------------
 
-QRect kpDocument::rect (bool ofSelection) const
+QRect kpDocument::rect(bool ofSelection) const
 {
     return (ofSelection && m_selection) ? m_selection->boundingRect() : m_image->rect();
 }
@@ -304,43 +283,37 @@ QRect kpDocument::rect (bool ofSelection) const
 //---------------------------------------------------------------------
 
 // public
-kpImage kpDocument::getImageAt (const QRect &rect) const
+kpImage kpDocument::getImageAt(const QRect &rect) const
 {
-    return kpPixmapFX::getPixmapAt (*m_image, rect);
+    return kpPixmapFX::getPixmapAt(*m_image, rect);
 }
 
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setImageAt (const kpImage &image, const QPoint &at)
+void kpDocument::setImageAt(const kpImage &image, const QPoint &at)
 {
 #if DEBUG_KP_DOCUMENT && 0
-    qCDebug(kpLogDocument) << "kpDocument::setImageAt (image (w="
-               << image.width ()
-               << ",h=" << image.height ()
-               << "), x=" << at.x ()
-               << ",y=" << at.y ();
+    qCDebug(kpLogDocument) << "kpDocument::setImageAt (image (w=" << image.width() << ",h=" << image.height() << "), x=" << at.x() << ",y=" << at.y();
 #endif
 
-    kpPixmapFX::setPixmapAt (m_image, at, image);
-    slotContentsChanged (QRect (at.x (), at.y (), image.width (), image.height ()));
+    kpPixmapFX::setPixmapAt(m_image, at, image);
+    slotContentsChanged(QRect(at.x(), at.y(), image.width(), image.height()));
 }
 
 //---------------------------------------------------------------------
 
 // public
-kpImage kpDocument::image (bool ofSelection) const
+kpImage kpDocument::image(bool ofSelection) const
 {
     kpImage ret;
 
-    if (ofSelection)
-    {
-        kpAbstractImageSelection *imageSel = imageSelection ();
-        Q_ASSERT (imageSel);
+    if (ofSelection) {
+        kpAbstractImageSelection *imageSel = imageSelection();
+        Q_ASSERT(imageSel);
 
-        ret = imageSel->baseImage ();
-    }
-    else {
+        ret = imageSel->baseImage();
+    } else {
         ret = *m_image;
     }
 
@@ -350,7 +323,7 @@ kpImage kpDocument::image (bool ofSelection) const
 //---------------------------------------------------------------------
 
 // public
-kpImage *kpDocument::imagePointer () const
+kpImage *kpDocument::imagePointer() const
 {
     return m_image;
 }
@@ -358,92 +331,88 @@ kpImage *kpDocument::imagePointer () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setImage (const kpImage &image)
+void kpDocument::setImage(const kpImage &image)
 {
-    m_oldWidth = width ();
-    m_oldHeight = height ();
+    m_oldWidth = width();
+    m_oldHeight = height();
 
     *m_image = image;
 
-    if (m_oldWidth == width () && m_oldHeight == height ()) {
-        slotContentsChanged (image.rect ());
-    }
-    else {
-        slotSizeChanged (QSize (width (), height ()));
+    if (m_oldWidth == width() && m_oldHeight == height()) {
+        slotContentsChanged(image.rect());
+    } else {
+        slotSizeChanged(QSize(width(), height()));
     }
 }
 
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setImage (bool ofSelection, const kpImage &image)
+void kpDocument::setImage(bool ofSelection, const kpImage &image)
 {
-    if (ofSelection)
-    {
-        kpAbstractImageSelection *imageSel = imageSelection ();
+    if (ofSelection) {
+        kpAbstractImageSelection *imageSel = imageSelection();
 
         // Have to have an image selection in order to set its pixmap.
-        Q_ASSERT (imageSel);
+        Q_ASSERT(imageSel);
 
-        imageSel->setBaseImage (image);
-    }
-    else {
-        setImage (image);
+        imageSel->setBaseImage(image);
+    } else {
+        setImage(image);
     }
 }
 
 //---------------------------------------------------------------------
 
-void kpDocument::fill (const kpColor &color)
+void kpDocument::fill(const kpColor &color)
 {
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "kpDocument::fill ()";
 #endif
 
     m_image->fill(color.toQRgb());
-    slotContentsChanged (m_image->rect ());
+    slotContentsChanged(m_image->rect());
 }
 
 //---------------------------------------------------------------------
 
-void kpDocument::resize (int w, int h, const kpColor &backgroundColor)
+void kpDocument::resize(int w, int h, const kpColor &backgroundColor)
 {
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "kpDocument::resize (" << w << "," << h << ")";
 #endif
 
-    m_oldWidth = width ();
-    m_oldHeight = height ();
+    m_oldWidth = width();
+    m_oldHeight = height();
 
 #if DEBUG_KP_DOCUMENT && 1
-    qCDebug(kpLogDocument) << "\toldWidth=" << m_oldWidth
-               << " oldHeight=" << m_oldHeight;
+    qCDebug(kpLogDocument) << "\toldWidth=" << m_oldWidth << " oldHeight=" << m_oldHeight;
 #endif
 
     if (w == m_oldWidth && h == m_oldHeight) {
         return;
     }
 
-    kpPixmapFX::resize (m_image, w, h, backgroundColor);
+    kpPixmapFX::resize(m_image, w, h, backgroundColor);
 
-    slotSizeChanged (QSize (width (), height ()));
+    slotSizeChanged(QSize(width(), height()));
 }
 
 //---------------------------------------------------------------------
 
-void kpDocument::slotContentsChanged (const QRect &rect)
+void kpDocument::slotContentsChanged(const QRect &rect)
 {
-    setModified ();
-    Q_EMIT contentsChanged (rect);
+    setModified();
+    Q_EMIT contentsChanged(rect);
 }
 
 //---------------------------------------------------------------------
 
-void kpDocument::slotSizeChanged (const QSize &newSize)
+void kpDocument::slotSizeChanged(const QSize &newSize)
 {
-    setModified ();
-    Q_EMIT sizeChanged (newSize.width(), newSize.height());
-    Q_EMIT sizeChanged (newSize);
+    setModified();
+    Q_EMIT sizeChanged(newSize.width(), newSize.height());
+    Q_EMIT sizeChanged(newSize);
 }
 
 //---------------------------------------------------------------------
